==> client-java-api-7.0.0-sources.jar: io/kubernetes/client/openapi/models/V2beta2HorizontalPodAutoscalerSpecFluent.java <==
package io.kubernetes.client.openapi.models;

import io.kubernetes.client.fluent.VisitableBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V2beta2HorizontalPodAutoscalerSpecFluent<A extends V2beta2HorizontalPodAutoscalerSpecFluent<A>> extends Fluent<A>{


    public Integer getMaxReplicas();
    public A withMaxReplicas(Integer maxReplicas);
    public Boolean hasMaxReplicas();
    public A addToMetrics(int index,V2beta2MetricSpec item);
    public A setToMetrics(int index,V2beta2MetricSpec item);
    public A addToMetrics(V2beta2MetricSpec... items);
    public A addAllToMetrics(Collection<V2beta2MetricSpec> items);
    public A removeFromMetrics(V2beta2MetricSpec... items);
    public A removeAllFromMetrics(Collection<V2beta2MetricSpec> items);
    public A removeMatchingFromMetrics(io.kubernetes.client.fluent.Predicate<V2beta2MetricSpecBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildMetrics instead.
 * @return The buildable object.
 */
@Deprecated public List<V2beta2MetricSpec> getMetrics();
    public List<V2beta2MetricSpec> buildMetrics();
    public V2beta2MetricSpec buildMetric(int index);
    public V2beta2MetricSpec buildFirstMetric();
    public V2beta2MetricSpec buildLastMetric();
    public V2beta2MetricSpec buildMatchingMetric(io.kubernetes.client.fluent.Predicate<V2beta2MetricSpecBuilder> predicate);
    public Boolean hasMatchingMetric(io.kubernetes.client.fluent.Predicate<V2beta2MetricSpecBuilder> predicate);
    public A withMetrics(List<V2beta2MetricSpec> metrics);
    public A withMetrics(V2beta2MetricSpec... metrics);
    public Boolean hasMetrics();
    public V2beta2HorizontalPodAutoscalerSpecFluent.MetricsNested<A> addNewMetric();
    public V2beta2HorizontalPodAutoscalerSpecFluent.MetricsNested<A> addNewMetricLike(V2beta2MetricSpec item);
    public V2beta2HorizontalPodAutoscalerSpecFluent.MetricsNested<A> setNewMetricLike(int index,V2beta2MetricSpec item);
    public V2beta2HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editMetric(int index);
    public V2beta2HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editFirstMetric();
    public V2beta2HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editLastMetric();
    public V2beta2HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editMatchingMetric(io.kubernetes.client.fluent.Predicate<V2beta2MetricSpecBuilder> predicate);
    public Integer getMinReplicas();
    public A withMinReplicas(Integer minReplicas);
    public Boolean hasMinReplicas();
    
/**
 * This method has been deprecated, please use method buildScaleTargetRef instead.
 * @return The buildable object.
 */
@Deprecated public V2beta2CrossVersionObjectReference getScaleTargetRef();
    public V2beta2CrossVersionObjectReference buildScaleTargetRef();
    public A withScaleTargetRef(V2beta2CrossVersionObjectReference scaleTargetRef);
    public Boolean hasScaleTargetRef();
    public V2beta2HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> withNewScaleTargetRef();
    public V2beta2HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> withNewScaleTargetRefLike(V2beta2CrossVersionObjectReference item);
    public V2beta2HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> editScaleTargetRef();
    public V2beta2HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> editOrNewScaleTargetRef();
    public V2beta2HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> editOrNewScaleTargetRefLike(V2beta2CrossVersionObjectReference item);

    public interface MetricsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta2MetricSpecFluent<V2beta2HorizontalPodAutoscalerSpecFluent.MetricsNested<N>>{

        
    public N and();    public N endMetric();
}
    public interface ScaleTargetRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta2CrossVersionObjectReferenceFluent<V2beta2HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<N>>{

        
    public N and();    public N endScaleTargetRef();
}


}

==> client-java-api-10.0.0-sources.jar: io/kubernetes/client/openapi/models/V2beta2HorizontalPodAutoscalerSpecFluent.java <==
package io.kubernetes.client.openapi.models;

import io.kubernetes.client.fluent.VisitableBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.kubernetes.client.fluent.Fluent;
import java.lang.Integer;
import java.util.Collection;

public interface V2beta2HorizontalPodAutoscalerSpecFluent<A extends V2beta2HorizontalPodAutoscalerSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildBehavior instead.
 * @return The buildable object.
 */
@Deprecated public V2beta2HorizontalPodAutoscalerBehavior getBehavior();
    public V2beta2HorizontalPodAutoscalerBehavior buildBehavior();
    public A withBehavior(V2beta2HorizontalPodAutoscalerBehavior behavior);
    public Boolean hasBehavior();
    public V2beta2HorizontalPodAutoscalerSpecFluent.BehaviorNested<A> withNewBehavior();
    public V2beta2HorizontalPodAutoscalerSpecFluent.BehaviorNested<A> withNewBehaviorLike(V2beta2HorizontalPodAutoscalerBehavior item);
    public V2beta2HorizontalPodAutoscalerSpecFluent.BehaviorNested<A> editBehavior();
    public V2beta2HorizontalPodAutoscalerSpecFluent.BehaviorNested<A> editOrNewBehavior();
    public V2beta2HorizontalPodAutoscalerSpecFluent.BehaviorNested<A> editOrNewBehaviorLike(V2beta2HorizontalPodAutoscalerBehavior item);
    public Integer getMaxReplicas();
    public A withMaxReplicas(Integer maxReplicas);
    public Boolean hasMaxReplicas();
    public A addToMetrics(int index,V2beta2MetricSpec item);
    public A setToMetrics(int index,V2beta2MetricSpec item);
    public A addToMetrics(V2beta2MetricSpec... items);
    public A addAllToMetrics(Collection<V2beta2MetricSpec> items);
    public A removeFromMetrics(V2beta2MetricSpec... items);
    public A removeAllFromMetrics(Collection<V2beta2MetricSpec> items);
    public A removeMatchingFromMetrics(io.kubernetes.client.fluent.Predicate<V2beta2MetricSpecBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildMetrics instead.
 * @return The buildable object.
 */
@Deprecated public List<V2beta2MetricSpec> getMetrics();
    public List<V2beta2MetricSpec> buildMetrics();
    public V2beta2MetricSpec buildMetric(int index);
    public V2beta2MetricSpec buildFirstMetric();
    public V2beta2MetricSpec buildLastMetric();
    public V2beta2MetricSpec buildMatchingMetric(io.kubernetes.client.fluent.Predicate<V2beta2MetricSpecBuilder> predicate);
    public Boolean hasMatchingMetric(io.kubernetes.client.fluent.Predicate<V2beta2MetricSpecBuilder> predicate);
    public A withMetrics(List<V2beta2MetricSpec> metrics);
    public A withMetrics(V2beta2MetricSpec... metrics);
    public Boolean hasMetrics();
    public V2beta2HorizontalPodAutoscalerSpecFluent.MetricsNested<A> addNewMetric();
    public V2beta2HorizontalPodAutoscalerSpecFluent.MetricsNested<A> addNewMetricLike(V2beta2MetricSpec item);
    public V2beta2HorizontalPodAutoscalerSpecFluent.MetricsNested<A> setNewMetricLike(int index,V2beta2MetricSpec item);
    public V2beta2HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editMetric(int index);
    public V2beta2HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editFirstMetric();
    public V2beta2HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editLastMetric();
    public V2beta2HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editMatchingMetric(io.kubernetes.client.fluent.Predicate<V2beta2MetricSpecBuilder> predicate);
    public Integer getMinReplicas();
    public A withMinReplicas(Integer minReplicas);
    public Boolean hasMinReplicas();
    
/**
 * This method has been deprecated, please use method buildScaleTargetRef instead.
 * @return The buildable object.
 */
@Deprecated public V2beta2CrossVersionObjectReference getScaleTargetRef();
    public V2beta2CrossVersionObjectReference buildScaleTargetRef();
    public A withScaleTargetRef(V2beta2CrossVersionObjectReference scaleTargetRef);
    public Boolean hasScaleTargetRef();
    public V2beta2HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> withNewScaleTargetRef();
    public V2beta2HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> withNewScaleTargetRefLike(V2beta2CrossVersionObjectReference item);
    public V2beta2HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> editScaleTargetRef();
    public V2beta2HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> editOrNewScaleTargetRef();
    public V2beta2HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> editOrNewScaleTargetRefLike(V2beta2CrossVersionObjectReference item);

    public interface BehaviorNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta2HorizontalPodAutoscalerBehaviorFluent<V2beta2HorizontalPodAutoscalerSpecFluent.BehaviorNested<N>>{

        
    public N and();    public N endBehavior();
}
    public interface MetricsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta2MetricSpecFluent<V2beta2HorizontalPodAutoscalerSpecFluent.MetricsNested<N>>{

        
    public N and();    public N endMetric();
}
    public interface ScaleTargetRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta2CrossVersionObjectReferenceFluent<V2beta2HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<N>>{

        
    public N and();    public N endScaleTargetRef();
}


}
